antares.apps.core.templatetags package
======================================

Submodules
----------

antares.apps.core.templatetags.core\_tags module
------------------------------------------------

.. automodule:: antares.apps.core.templatetags.core_tags
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: antares.apps.core.templatetags
   :members:
   :undoc-members:
   :show-inheritance:
